pagebotcocoa.apps.canvas package
================================

Submodules
----------

pagebotcocoa.apps.canvas.canvas module
--------------------------------------

.. automodule:: pagebotcocoa.apps.canvas.canvas
   :members:
   :undoc-members:
   :show-inheritance:

pagebotcocoa.apps.canvas.canvasview module
------------------------------------------

.. automodule:: pagebotcocoa.apps.canvas.canvasview
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: pagebotcocoa.apps.canvas
   :members:
   :undoc-members:
   :show-inheritance:
